@@ -165,9 +165,8 @@ teststr { form("([[[[]])","a b c def ghijklm") }
 
 # ALIGNED NUMERICAL FORMATTING
 
-teststr { form("***]]]].[[[[***","NaN 1 1.1 1.00001 1.00009 1.2345 1.23456 1111 12345.54321 a0 b 0") }
-"***????.????***
-***   1.0   ***
+teststr { form("***]]]].[[[[***","1 1.1 1.00001 1.00009 1.2345 1.23456 1111 12345.54321 a0 b 0") }
+"***   1.0   ***
 ***   1.1   ***
 ***   1.0000***
 ***   1.0001***
@@ -180,7 +179,7 @@ teststr { form("***]]]].[[[[***","NaN 1 1.1 1.00001 1.00009 1.2345 1.23456 1111
 ***   0.0   ***
 ";
 
-teststr { form( { numeric => 'SkipNaN,AllPlaces' }, "***]]]].[[[[***","NaN 1 1.1 1.00001 1.00009 1.2345 1.23456 1111 12345.54321 a0 b 0") }
+teststr { form( { numeric => 'SkipNaN,AllPlaces' }, "***]]]].[[[[***","1 1.1 1.00001 1.00009 1.2345 1.23456 1111 12345.54321 a0 b 0") }
 "***   1.0000***
 ***   1.1000***
 ***   1.0000***
